package com.anyway.favor.controller;

import com.anyway.favor.model.User;
import com.anyway.favor.service.UserService;
import com.anyway.util.JwtUtils;
import com.anyway.util.PageQuery;
import com.anyway.util.R;
import com.google.common.collect.ImmutableMap;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 用户接口
 *
 * @author liuchuanwei
 * @date 2024-08-15
 */
@Slf4j
@RestController
@RequestMapping("/user")
public class UserController {

    @Autowired
    private UserService userService;


    @PostMapping("/login")
    public R<Void> login(@RequestBody User user, HttpServletResponse response) {
        log.info("登录表单：{}", user);
        User loginUser = userService.findByUserName(user.getUserName());
        if (loginUser == null || !loginUser.getPassword().equals(user.getPassword())) {
            return R.fail("用户名或密码错误");
        }
        //生成token并返回
        Map<String, Object> map = ImmutableMap.of("userName", loginUser.getUserName());
        String token = JwtUtils.createToken(map);
        response.setHeader(JwtUtils.TOKEN_HEADER, token);
        return R.ok();
    }


    @PostMapping("/list")
    public R<List<User>> list(@RequestBody PageQuery<Map<String, Object>> pageQuery) {
        Map<String, Object> terms = pageQuery.getTerms(new HashMap<>());
        List<User> userList = userService.findPage(pageQuery);
        return R.page(userList, pageQuery.getPage());
    }

    @PostMapping("/save")
    public R<Void> save(@RequestBody User user) {
        log.info("用户：{}", user);
        userService.save(user);
        return R.ok();
    }

    @GetMapping("/delete")
    public R<Void> delete(@RequestParam Long id) {
        log.info("用户：{}", id);
        userService.deleteById(id);
        return R.ok();
    }

    @GetMapping("/detail")
    public R<User> detail(@RequestParam Long id) {
        log.info("用户：{}", id);
        return R.data(userService.findById(id));
    }
}
